How To Install?

pip install StrooAi
pip install JarvisAi

How To Use?

from StrooAi import *

Code Exsamples

StruanSpeek(Text_To_Speek)
StruanSpeekAndPrint(Text_To_Speek_An_Print)
StruanLissen()
StruanTellMeAbout(Topic_to_Tell_You)
StruanTime()
StruanDate()
StruanWeather(City)
StruanNews()
StruanWeb(Link_To_The_Site_To_Open)
StruanWebNewTab(Link_To_The_Site_To_Open)
StruanJoke()

How Do You Exstracting The Data?

for StruanLissen()
StruanLissen.Lissener
{code exsample}

from StrooAi import *

StruanLissen()

print(StruanLissen.Lissener)


for StruanTellMeAbout(Topic_to_Tell_You)
StruanTellMeAbout.Topic
{code exsample}

from StrooAi import *

StruanTellMeAbout('fish')

print(StruanTellMeAbout.Topic)


for StruanTime()
StruanTime.Time
{code exsample}

from StrooAi import *

StruanTime()

print(StruanTime.Time)


for StruanDate()
StruanDate.Date
{code exsample}

from StrooAi import *

StruanDate()

print(StruanTime.Date)


for StruanWeather(City)
StruanWeather.CityWeather
{code exsample}

from StrooAi import *

StruanWeather('Abrdeen')

print(StruanWeather.CityWeather)


for StruanNews()
StruanNews.News
{code exsample}

from StrooAi import *

StruanNews()

print(StruanNews.News)


for StruanJoke()
StruanJoke.Joke
{code exsample}

from StrooAi import *

StruanJoke()

print(StruanJoke.Joke)

Made By StruanMclean